@@ -28,12 +28,22 @@ class QVariantTypeName(unittest.TestCase):
         obj = QVariant(Qt.SolidLine)
         self.assertEqual('int', obj.typeName())
 
-class QVariantQColorImplicitlyConvertion(unittest.TestCase):
+class QVariantImplicitlyConvertion(unittest.TestCase):
     def testConversions(self):
         c1 = QColor(0, 0, 0)
         v = QVariant(c1)
         c2 = QColor(v)
         self.assertEqual(c1, c2)
 
+    def testQIconConversion(self):
+        app = QApplication([])
+
+        i = QIcon()
+        w = QTableWidgetItem("")
+        w.setData(Qt.DecorationRole, i)
+
+        c = QColor()
+        w.setData(Qt.DecorationRole, c)
+
 if __name__ == '__main__':
     unittest.main()
